@@ -2,8 +2,6 @@
 
 import logging
 
-from pydantic import BaseModel
-
 from cg.utils.utils import get_hamming_distance
 
 LOG = logging.getLogger(__name__)
@@ -16,13 +14,6 @@ def is_dual_index(index: str) -> bool:
     return "-" in index
 
 
-class Index(BaseModel):
-    """Class that represents an index."""
-
-    name: str
-    sequence: str
-
-
 def get_reverse_complement_dna_seq(dna: str) -> str:
     """Generates the reverse complement of a DNA sequence."""
     LOG.debug(f"Reverse complement string {dna}")
