@@ -2,10 +2,11 @@
 
 import logging
 
-import click
+import rich_click as click
 
 from cg.cli.delete.case import delete_case
 from cg.cli.delete.cases import delete_cases
+from cg.cli.delete.illumina_sequencing_run import delete_illumina_run
 from cg.cli.delete.observations import (
     delete_available_observations,
     delete_observations,
@@ -25,3 +26,4 @@ delete.add_command(delete_case)
 delete.add_command(delete_cases)
 delete.add_command(delete_observations)
 delete.add_command(delete_available_observations)
+delete.add_command(delete_illumina_run)
