@@ -2,18 +2,18 @@
 
 import logging
 
-import click
+import rich_click as click
 from pydantic import ValidationError
 
 from cg.cli.workflow.commands import ARGUMENT_CASE_ID
 from cg.cli.workflow.utils import validate_force_store_option
-from cg.constants import EXIT_FAIL, EXIT_SUCCESS
-from cg.constants.cli_options import DRY_RUN, FORCE, COMMENT
+from cg.constants import EXIT_FAIL, EXIT_SUCCESS, Workflow
+from cg.constants.cli_options import COMMENT, DRY_RUN, FORCE
 from cg.constants.constants import MetaApis
 from cg.exc import AnalysisNotReadyError, CgError, HousekeeperStoreError
 from cg.meta.workflow.nf_analysis import NfAnalysisAPI
-
 from cg.models.cg_config import CGConfig
+from cg.store.models import Case
 
 LOG = logging.getLogger(__name__)
 
@@ -37,12 +37,6 @@ OPTION_PROFILE = click.option(
     help="Choose a configuration profile",
 )
 
-OPTION_LOG = click.option(
-    "--log",
-    type=click.Path(),
-    help="Set nextflow log file path",
-)
-
 OPTION_CONFIG = click.option(
     "--config",
     type=click.Path(),
@@ -88,6 +82,13 @@ OPTION_FROM_START = click.option(
     show_default=True,
     help="Start workflow from start without resuming execution",
 )
+OPTION_STUB = click.option(
+    "--stub-run",
+    is_flag=True,
+    default=False,
+    show_default=True,
+    help="Start a stub workflow",
+)
 
 
 @click.command("config-case")
@@ -106,7 +107,6 @@ def config_case(context: CGConfig, case_id: str, dry_run: bool) -> None:
 
 @click.command("run")
 @ARGUMENT_CASE_ID
-@OPTION_LOG
 @OPTION_WORKDIR
 @OPTION_FROM_START
 @OPTION_PROFILE
@@ -116,12 +116,12 @@ def config_case(context: CGConfig, case_id: str, dry_run: bool) -> None:
 @OPTION_COMPUTE_ENV
 @OPTION_USE_NEXTFLOW
 @OPTION_TOWER_RUN_ID
+@OPTION_STUB
 @DRY_RUN
 @click.pass_obj
 def run(
     context: CGConfig,
     case_id: str,
-    log: str,
     work_dir: str,
     from_start: bool,
     profile: str,
@@ -131,6 +131,7 @@ def run(
     compute_env: str,
     use_nextflow: bool,
     nf_tower_id: str | None,
+    stub_run: bool,
     dry_run: bool,
 ) -> None:
     """Run analysis for a case."""
@@ -139,7 +140,6 @@ def run(
         analysis_api.run_nextflow_analysis(
             case_id=case_id,
             dry_run=dry_run,
-            log=log,
             work_dir=work_dir,
             from_start=from_start,
             profile=profile,
@@ -149,6 +149,7 @@ def run(
             compute_env=compute_env,
             use_nextflow=use_nextflow,
             nf_tower_id=nf_tower_id,
+            stub_run=stub_run,
         )
     except Exception as error:
         LOG.error(f"Unspecified error occurred: {error}")
@@ -157,7 +158,6 @@ def run(
 
 @click.command("start")
 @ARGUMENT_CASE_ID
-@OPTION_LOG
 @OPTION_WORKDIR
 @OPTION_PROFILE
 @OPTION_CONFIG
@@ -165,12 +165,12 @@ def run(
 @OPTION_REVISION
 @OPTION_COMPUTE_ENV
 @OPTION_USE_NEXTFLOW
+@OPTION_STUB
 @DRY_RUN
 @click.pass_obj
 def start(
     context: CGConfig,
     case_id: str,
-    log: str,
     work_dir: str,
     profile: str,
     config: str,
@@ -178,6 +178,7 @@ def start(
     revision: str,
     compute_env: str,
     use_nextflow: bool,
+    stub_run: bool,
     dry_run: bool,
 ) -> None:
     """Start workflow for a case."""
@@ -185,12 +186,13 @@ def start(
     analysis_api: NfAnalysisAPI = context.meta_apis[MetaApis.ANALYSIS_API]
     try:
         analysis_api.status_db.verify_case_exists(case_internal_id=case_id)
-        analysis_api.prepare_fastq_files(case_id=case_id, dry_run=dry_run)
+        case: Case = analysis_api.status_db.get_case_by_internal_id(case_id)
+        if case.data_analysis != Workflow.NALLO:
+            analysis_api.prepare_fastq_files(case_id=case_id, dry_run=dry_run)
         analysis_api.config_case(case_id=case_id, dry_run=dry_run)
         analysis_api.run_nextflow_analysis(
             case_id=case_id,
             dry_run=dry_run,
-            log=log,
             work_dir=work_dir,
             from_start=True,
             profile=profile,
@@ -199,6 +201,7 @@ def start(
             revision=revision,
             compute_env=compute_env,
             use_nextflow=use_nextflow,
+            stub_run=stub_run,
         )
     except Exception as error:
         LOG.error(f"Unexpected error occurred: {error}")
@@ -212,7 +215,7 @@ def start_available(context: click.Context, dry_run: bool = False) -> None:
     """Start workflow for all cases ready for analysis."""
     analysis_api: NfAnalysisAPI = context.obj.meta_apis[MetaApis.ANALYSIS_API]
     exit_code: int = EXIT_SUCCESS
-    for case in analysis_api.get_cases_ready_for_analysis():
+    for case in analysis_api.get_cases_to_analyze():
         try:
             context.invoke(start, case_id=case.internal_id, dry_run=dry_run)
         except AnalysisNotReadyError as error:
@@ -318,11 +321,13 @@ def store_available(context: click.Context, dry_run: bool) -> None:
     """
 
     analysis_api: NfAnalysisAPI = context.obj.meta_apis[MetaApis.ANALYSIS_API]
-
+    was_successful: bool = True
     for case in analysis_api.get_cases_to_store():
         LOG.info(f"Storing deliverables for {case.internal_id}")
         try:
             analysis_api.store(case_id=case.internal_id, dry_run=dry_run)
         except Exception as error:
             LOG.error(f"Error storing {case.internal_id}: {repr(error)}")
-            raise click.Abort
+            was_successful = False
+    if not was_successful:
+        raise click.Abort()
