@@ -11,7 +11,6 @@ from pydantic.v1 import ValidationError
 
 from cg.constants import Workflow
 from cg.constants.constants import (
-    CaseActions,
     FileExtensions,
     FileFormat,
     GenomeVersion,
@@ -91,12 +90,6 @@ class NfAnalysisAPI(AnalysisAPI):
     def process(self, process: Process):
         self._process = process
 
-    @property
-    def use_read_count_threshold(self) -> bool:
-        """Defines whether the threshold for adequate read count should be passed for all samples
-        when determining if the analysis for a case should be automatically started."""
-        return True
-
     @property
     def sample_sheet_headers(self) -> list[str]:
         """Headers for sample sheet."""
