@@ -30,7 +30,7 @@ class SubprocessSubmitter(Submitter):
         """
         try:
             command: str = WORKFLOW_VERSION_COMMAND_MAP[case_config.workflow]
-            command = command.format(case_config.model_dump())
+            command = command.format(**case_config.model_dump())
             LOG.debug(f"Running: {command}")
             result: subprocess.CompletedProcess = subprocess.run(
                 args=command,
@@ -40,7 +40,7 @@ class SubprocessSubmitter(Submitter):
                 stderr=subprocess.PIPE,
             )
             stdout: str = result.stdout.decode("utf-8").rstrip()
-            return list(stdout)[0].split()[-1]
+            return stdout.split()[-1]
         except Exception:
             LOG.warning(f"Could not retrieve {case_config.workflow} workflow version!")
             return "0.0.0"
