@@ -1,6 +1,7 @@
 from pathlib import Path
 
 from cg.constants.constants import FileExtensions, WorkflowManager
+from cg.services.analysis_starter.configurator.models.nextflow import NextflowCaseConfig
 from cg.services.analysis_starter.tracker.tracker import Tracker
 
 
@@ -11,3 +12,6 @@ class NextflowTracker(Tracker):
     def _get_job_ids_path(self, case_id: str) -> Path:
         """Return the path to a Trailblazer config file containing Tower IDs."""
         return Path(self.workflow_root, case_id, "tower_ids").with_suffix(FileExtensions.YAML)
+
+    def _get_workflow_version(self, case_config: NextflowCaseConfig) -> str:
+        return case_config.revision
