@@ -3,6 +3,7 @@ from typing import Callable
 
 from sqlalchemy.orm import Query
 
+from cg.constants.sequencing import SeqLibraryPrepCategory
 from cg.store.models import Application
 
 
@@ -26,12 +27,22 @@ def filter_applications_is_not_external(applications: Query, **kwargs) -> Query:
     return applications.filter(Application.is_external == False)
 
 
+def filter_applications_has_versions(applications: Query, **kwargs) -> Query:
+    return applications.filter(Application.versions.any())
+
+
+def filter_application_by_prep_categories(
+    applications: Query, prep_categories: list[SeqLibraryPrepCategory], **kwargs
+) -> Query:
+    """Return application corresponding to dna sequencing."""
+    return applications.filter(Application.prep_category.in_(prep_categories))
+
+
 def apply_application_filter(
     filter_functions: list[Callable],
     applications: Query,
     tag: str = None,
-    prep_category: str = None,
-    entry_id: int = None,
+    prep_categories: list[SeqLibraryPrepCategory] = None,
 ) -> Query:
     """Apply filtering functions to the sample queries and return filtered results."""
 
@@ -39,8 +50,7 @@ def apply_application_filter(
         applications: Query = filter_function(
             applications=applications,
             tag=tag,
-            prep_category=prep_category,
-            entry_id=entry_id,
+            prep_categories=prep_categories,
         )
     return applications
 
@@ -48,7 +58,9 @@ def apply_application_filter(
 class ApplicationFilter(Enum):
     """Define Application filter functions."""
 
+    HAS_VERSIONS = filter_applications_has_versions
     IS_EXTERNAL = filter_applications_is_external
     IS_NOT_EXTERNAL = filter_applications_is_not_external
     BY_TAG = filter_applications_by_tag
     IS_NOT_ARCHIVED = filter_applications_is_not_archived
+    BY_PREP_CATEGORIES = filter_application_by_prep_categories
